@@ -14,7 +14,7 @@ from stdcomqt5 import *
 from stdcomqt5widget import *
 
 
-class pjaniceGeneric(QDialog):
+class pjaniceGeneric(QWidget):
     """
     Stec Pjanice Widget, but with trees not list.
     """
@@ -31,7 +31,7 @@ class pjaniceGeneric(QDialog):
     liveSubscriptions = {"": []}
     liveSubscriptionsData = {"": []}
 
-    def __init__(self, cBridge: stdcomPyQt = None, project: str = "stec-pjanice"):
+    def __init__(self, cBridge: stdcomPyQt = None, project: str = "stec-pjanice", parent = None):
         """
          def __init__(self, cBridge : stdcomPyQt = None):
         :param cBridge: If you are passing a cBridge and it is controlled here, pass it else it will make one
@@ -41,7 +41,7 @@ class pjaniceGeneric(QDialog):
         self.liveSubscriptions.clear()
 
         self.project = project
-        super().__init__()
+        super().__init__(parent)
         self.ui = Ui_pjanice()
         self.ui.setupUi(self)
 
@@ -307,7 +307,7 @@ if __name__ == "__main__":
     bumped version
     """
 
-    my_parser = argparse.ArgumentParser( description="Version 1.5.1 Stec Pjanice Python Version")
+    my_parser = argparse.ArgumentParser( description="Version 1.5.2 Stec Pjanice Python Version")
     # Add the arguments
     my_parser.add_argument('-p','--project', metavar='project', required=False)
 
@@ -329,4 +329,4 @@ if __name__ == "__main__":
     # Start the event loop.
     app.exec_()
     if window.cBridge != None:
-        window.Terminate()
+        window.cBridge.terminate()
