@@ -59,6 +59,7 @@ class stdcom:
     _Callback = None
     _NCallback = None
     _ECallback = None
+    _DCallback = None
 
     nbrAcks = 1
     isopen = False
@@ -73,11 +74,12 @@ class stdcom:
         self._t = Thread(target=self.run)
         self._t.start()
 
-    def __init__(self, ipaddress, port, connectedFunction  =None, Callback=None, NCallback=None, ECallback = None):
+    def __init__(self, ipaddress, port, connectedFunction  =None, Callback=None, NCallback=None, ECallback = None, DCallback = None):
 
         self._running = True
         self.activeData = {"": []} # todo need a way to stop collecting it down higher up
         self._outQueue = queue.Queue()
+        self._outDescQueue = queue.Queue()
         self._outNameList = list()
         self.s = None
         try:
@@ -92,6 +94,8 @@ class stdcom:
         self._Callback = Callback
         self._NCallback = NCallback
         self._ECallback = ECallback
+        self._DCallback = DCallback
+
         self.connectedCallback = connectedFunction
 
         try:
@@ -145,7 +149,7 @@ class stdcom:
             self.AddSubscriptions(toDo)
         return data
 
-    def SetCallbacks(self, callback = None, namecallback = None):
+    def SetCallbacks(self, callback = None, namecallback = None, desccallback = None):
 
         """
         SetCallbacks  sets the Data and
@@ -155,6 +159,7 @@ class stdcom:
         with self.conditionValue:
             self._Callback = callback
             self._NCallback = namecallback
+            self._DCallback = desccallback
 
     def terminate(self):
 
@@ -342,6 +347,21 @@ class stdcom:
                     if self._ECallback != None:
                         self._ECallback()
 
+    def UpdateDescription(self, who, what ):
+
+         command = "UPDATE-DESC," + who + "," + what
+         command += "\n"
+         with self.conditionValue:
+
+            try:
+                    self.s.send(command.encode("ascii"))
+            except OSError as e:
+                print("Caught exception socket.error : ", e)
+                self.isopen = False
+                if self._ECallback != None:
+                    self._ECallback()
+
+
     def UpdateRaw(self, who, what, index):
 
         """
@@ -394,6 +414,19 @@ class stdcom:
             self._outQueue = queue.Queue()
             return out
 
+    def GetDescNotifications(self):
+
+        """
+        If callback are not used, user can call this and it returns changed subsriptions, Use callbacks it makes more sense
+
+            :return: list of subs that should be read if call backs are not used
+
+        """
+        with self.conditionValue:
+            out = self._outDescQueueQueue
+            self._outDescQueueQueue = queue.Queue()
+            return out
+
     def AddSubscriptions(self, subs):
         """
         Adds a list of subscriptions
@@ -497,11 +530,33 @@ class stdcom:
                         with self.conditionValue:
                             CB = self._Callback
 
-                            if CB == 0:
+                            if CB == None:
                                 self._outQueue.put(sub)
                         if CB:
                             CB(sub)
 
+                elif 'UPDATE-DESC' in row[0]:
+                    try :
+                        indx = scsv.index(",")
+                        data = scsv[indx + 1: len(scsv)]
+
+                        d=[ data]
+
+                        sub = Subscription()
+                        sub.SetData(name, d)
+
+                        with self.conditionValue:
+                            CB = self._DCallback
+
+                            if CB == None:
+                                self._outDescQueue.put(sub)
+                        if CB:
+                            CB(sub)
+                    except :
+                        print("Desc Error")
+
+
+
                 elif 'ACK' in row[0] :
                     with self.conditionValue:
                         self.nbrAcks = self.nbrAcks + 1
@@ -516,7 +571,7 @@ if __name__ == "__main__":
     from time import sleep
     import sys
     if "--version" in sys.argv :
-        print("1.2.3")
+        print("1.5.00")
         sys.exit()
 
 
@@ -536,7 +591,7 @@ if __name__ == "__main__":
 
 
     # this could be argv but we will weld it for now
-    XHOST = "192.168.199.7"  # we talk to ourself
+    XHOST = "192.168.199.245"  # we talk to ourself
     XPORT = int(4897)  # service port for NextStep plugin
 
     XSUBS = ["Scanner1.moisture", "Scannner1.basiswt"]
@@ -552,8 +607,6 @@ if __name__ == "__main__":
         for i in range(0, len(XSUBS)):
             cBridge.UpdateAsFloat(XSUBS[i], s1, 0)
 
-
-
     except:
         print("Check IP or Ensure NextStep Plugin is running")
 
